@@ -4,6 +4,8 @@ import copy
 import json
 import logging
 import pathlib
+import glob
+import uuid
 import os.path
 from string import Template
 from time import sleep
@@ -19,6 +21,7 @@ from datahub.metadata.schema_classes import (
 from datahub.emitter.mce_builder import make_tag_urn, make_user_urn
 from datahub.emitter.mcp import MetadataChangeProposalWrapper
 
+from metadata.ensure import ensure_true
 from metadata.utils.lang import clean_nones
 from metadata.exception import MetadataException
 from metadata.context import MetadataContext
@@ -47,7 +50,7 @@ class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin):
         )
         return aspect
 
-    def _get_tags_aspect(self, tags: list[str]):
+    def _get_tags_aspect(self, tags: List[str]):
         aspect = GlobalTagsClass(
             [TagAssociationClass(make_tag_urn(tag)) for tag in (tags or [])]
         )
@@ -95,7 +98,7 @@ class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin):
             )      
             self.context.emitter.emit(metadata_event)
     
-    def _get_entities_by_facts(self, entity_type: str, facts: List[Tuple[str, str, bool, str]], *, search: str=''):
+    def _get_entities_by_facts(self, entity_type: str, facts: List[Tuple[str, str, bool, str]], *, search: str='', start=0, count=1000):
         conditions = ""
         for field, values, negated, condition in facts:
             values = "[%s]" % (", ".join([json.dumps(str(value)) for value in values]))
@@ -103,9 +106,38 @@ class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin):
             conditions += f"""\n{{\n field: "{field}"\n values: {values}\n negated: {negated}\n condition: {condition}\n}}\n"""
         rs = self._query_graphql('searchAcrossEntities',
             conditions=conditions,
-            types=entity_type.upper(), start=0, count=1000, search=search)['data']['searchAcrossEntities']
+            types=entity_type.upper(), start=start, count=count, search=search)['data']['searchAcrossEntities']
 
         return [r['entity']['urn'] for r in rs['searchResults']]
 
     def _get_current_user(self):
-        return self._query_graphql('me')['data']['me']['corpUser']
\ No newline at end of file
+        return self._query_graphql('me')['data']['me']['corpUser']
+
+    def get_entities_by_browse_path(self, entity_type: str, path: str, *, start=0, count=1000):        
+        return [r['urn'] for r in self._query_graphql("browse", type=entity_type, path=path, start=start, count=count)['data']['browse']['entities']]
+
+    def upload_artifact(self, storage_prefix, path_prefix, source):
+        storage_client = self.context.storage_client
+        ensure_true(storage_client, 'Storage Client required for context')
+        prefix = storage_prefix or uuid.uuid4().hex
+        from dflow import s3_config
+        uri = os.path.join(s3_config["prefix"], prefix)
+        prefix = uri
+        source = os.path.abspath(source)
+        if os.path.isdir(source):
+            files = [(i[len(source)+1:], i) for i in glob.glob(f'{source}/**/*', recursive=True) if not os.path.isdir(i)]
+        else:
+            files = [(os.path.basename(source), source)]
+        
+        from dflow import upload_s3
+        for suffix_key, file in files:
+            print(prefix, path_prefix, suffix_key)
+            key = os.path.join(prefix, path_prefix or '', suffix_key)
+            print(file, key, prefix)
+            upload_s3(file, key=key, prefix=uri)
+        return uri
+    
+    def delete_artifact(self, key):
+        storage_client = self.context.storage_client
+        ensure_true(storage_client, 'Storage Client required for context')
+        storage_client.delete
\ No newline at end of file
