@@ -1,14 +1,15 @@
 # -*- encoding: utf-8 -*-
 
 import copy
+import glob
 import os.path
 import logging
-from typing import List
+from typing import List, Optional
 
 from datahub.emitter.mce_builder import make_tag_urn, make_user_urn
 from datahub.metadata.schema_classes import DatasetPropertiesClass, ContainerClass, ChangeTypeClass
 
-from metadata.ensure import ensure_type
+from metadata.ensure import ensure_type, ensure_true
 from metadata.entity.dataset import Dataset
 
 
@@ -34,6 +35,26 @@ class DatasetMixin:
         self._emit_aspects(Dataset.entity_type, dataset.urn, filter(None, [dataset_properties, global_tags, owner_aspect, container_aspect]))
         return dataset.urn
 
+    def migrate_dataset(self,  dataset: Dataset, urn: str, upsert=True):
+        ensure_type(dataset, Dataset)
+
+        r = self._query_graphql(Dataset.entity_type, urn=urn)['data']['dataset']['editableDatasetProperties']
+
+        properties = copy.deepcopy(dataset.properties)
+        properties['uri'] = dataset.uri
+        dataset_properties = DatasetPropertiesClass(
+            name=dataset.display_name,
+            customProperties=properties,
+            description=dataset.description,
+        )
+        global_tags = self._get_tags_aspect(dataset.tags)
+        owner_aspect = self._get_ownership_aspect(dataset.owners or [self.context.user_email])
+        container_aspect = ContainerClass(
+            dataset.group
+        ) if dataset.group else None
+        self._emit_aspects(Dataset.entity_type, dataset.urn, filter(None, [dataset_properties, global_tags, owner_aspect, container_aspect]))
+        return dataset.urn
+
     def update_dataset(self, dataset: Dataset):
         return self.create_dataset(dataset, upsert=True)
 
@@ -61,7 +82,7 @@ class DatasetMixin:
     def delete_dataset(self, urn: str, soft=True):
         return self._delete_entity(urn, soft=soft)
     
-    def get_datasets_by_facts(self, *, owner: str=None, group: str=None, tags: List[str]=None, search: str=''):
+    def get_datasets_by_facts(self, *, owner: str=None, group: str=None, tags: List[str]=None, search: str='', start=0, count=1000):
         facts = []
         if group:
             facts.append(('container', [group], False, 'EQUAL'))
@@ -69,4 +90,17 @@ class DatasetMixin:
             facts.append(('tags', [make_tag_urn(tag) for tag in tags], False, 'CONTAIN'))
         if owner:
             facts.append(('owners', [make_user_urn(self.context.user_email if owner == 'me' else owner), False, 'CONTAIN']))
-        return self._get_entities_by_facts(Dataset.entity_type, facts, search=search)
\ No newline at end of file
+        return self._get_entities_by_facts(Dataset.entity_type, facts, search=search, start=start, count=count)
+    
+    def download_dataset(self, urn: str, dest: str, sub_paths: Optional[List[str]]):
+        dataset = self.get_dataset(urn)
+        storage_client = self.context.storage_client
+        ensure_true(storage_client, 'Storage Client required for context')
+        files = storage_client.list(dataset.uri, recursive=True)
+        sub_paths = tuple(sub_paths) if sub_paths else None
+        for file in files:
+            rfile = file[len(dataset.uri)+1:]
+            if sub_paths and not rfile.startswith(sub_paths):
+                continue
+            target = os.path.abspath(os.path.join(dest, rfile))
+            storage_client.download(file, target)
