@@ -57,17 +57,17 @@ class DatasetGroupMixin:
             if sync_wait:
                 self._sync_check(f'change {urn} group to {group_urn}', lambda : urn not in self.get_datasets_by_group(group_urn))
     
-    def get_datasets_by_group(self, group_urn: str):
+    def get_datasets_by_group(self, group_urn: str, *, start=0, count=1000):
         if not self.check_entity_exists(group_urn):
             raise MetadataAssertionError(f'DatasetGroup(urn={group_urn}) does not exists')
-        r = self._query_graphql('container.relationships', urn=group_urn, types='IsPartOf', direction='INCOMING', start=0, count=10000)
+        r = self._query_graphql('container.relationships', urn=group_urn, types='IsPartOf', direction='INCOMING', start=start, count=count)
         rr = r['data']['container']['relationships']
         return [i['entity']['urn'] for i in rr['relationships']]
 
-    def get_dataset_groups_by_facts(self, *, owner: str=None, tags: List[str]=None, search: str=''):
+    def get_dataset_groups_by_facts(self, *, owner: str=None, tags: List[str]=None, search: str='', start=0, count=1000):
         facts = []
         if tags:
             facts.append(('tags', [make_tag_urn(tag) for tag in tags], False, 'CONTAIN'))
         if owner:
             facts.append(('owners', [make_user_urn(self.context.user_email if owner == 'me' else owner)], False, 'CONTAIN'))
-        return self._get_entities_by_facts(DatasetGroup.entity_type, facts, search=search)
\ No newline at end of file
+        return self._get_entities_by_facts(DatasetGroup.entity_type, facts, search=search, start=start, count=count)
\ No newline at end of file
