@@ -71,17 +71,17 @@ class ModelGroupMixin:
             if sync_wait:
                 self._sync_check(f'remove {urn} from {group_urn}', lambda : urn not in self.get_models_by_group(group_urn))
     
-    def get_models_by_group(self, group_urn: str):
+    def get_models_by_group(self, group_urn: str, *, start=0, count=1000):
         if not self.check_entity_exists(group_urn):
             raise MetadataAssertionError(f'ModelGroup(urn={group_urn}) does not exists')
-        r = self._query_graphql('mlModelGroup.relationships', urn=group_urn, types='MemberOf', direction='INCOMING', start=0, count=10000)
+        r = self._query_graphql('mlModelGroup.relationships', urn=group_urn, types='MemberOf', direction='INCOMING', start=start, count=count)
         rr = r['data']['mlModelGroup']['relationships']
         return [i['entity']['urn'] for i in rr['relationships']]
     
-    def get_model_groups_by_facts(self, *, owner: str=None, tags: List[str]=None, search: str=''):
+    def get_model_groups_by_facts(self, *, owner: str=None, tags: List[str]=None, search: str='', start=0, count=10000):
         facts = []
         if tags:
             facts.append(('tags', [make_tag_urn(tag) for tag in tags], False, 'CONTAIN'))
         if owner:
             facts.append(('owners', [make_user_urn(self.context.user_email if owner == 'me' else owner)], False, 'CONTAIN'))
-        return self._get_entities_by_facts('MLMODEL_GROUP', facts, search=search)
\ No newline at end of file
+        return self._get_entities_by_facts('MLMODEL_GROUP', facts, search=search, start=start, count=count)
\ No newline at end of file
