@@ -27,7 +27,7 @@ local = threading.local()
 logger = logging.getLogger(__name__)
 urllib3.disable_warnings(category=InsecureRequestWarning)
 
-__all__ = ['MetadataContext']
+__all__ = ['MetadataContext', 'get_current_context']
 
 
 class MetadataContext(object):
@@ -35,7 +35,8 @@ class MetadataContext(object):
     def __init__(self, endpoint=None, token=None, *,
             project='default',
             env=ENV_TYPE.CORP,
-            options=None):
+            options=None,
+            storage_client=None):
 
         endpoint = endpoint or os.getenv('DATAHUB_GMS_URL')
         token = token or os.getenv('DATAHUB_GMS_TOKEN')
@@ -44,7 +45,6 @@ class MetadataContext(object):
         token = ensure_token_format(token)
         ensure_project_format(project)
         ensure_env_enum(env)
-
         self.endpoint = build_url(endpoint, '')
         self.token = token
         if not self.token:
@@ -60,6 +60,8 @@ class MetadataContext(object):
         self.debug = False
         self.options = self._load_options(**(options or {}))
 
+        self.storage_client = storage_client
+
     @staticmethod
     def _load_options(**kwargs):
         options = {
@@ -93,18 +95,6 @@ class MetadataContext(object):
         self.started = True
         return self
 
-    def _fixup_gateway_scheme(self):
-        timeout = self.options.get('defaults.metadata.context.request_timeout', (3, 10))
-        try:
-            resp = requests.post(self.endpoint, verify=False, allow_redirects=False, timeout=timeout)
-            if resp.status_code != 302:
-                return
-            new_endpoint = build_url(resp.headers['Location'], '/', {})
-            logger.warning('automatic detect endpoint change %s -> %s', self.endpoint, new_endpoint)
-            self.endpoint = new_endpoint
-        except ConnectionError:
-            pass
-
     def __exit__(self, exc_type, exc_value, exc_tb):
         if not self.started:
             raise MetadataContextError('%s not start' % self)
@@ -222,3 +212,21 @@ class MetadataContext(object):
     def client(self):
         from metadata.client.client import Client
         return Client(self)
+
+
+def get_current_context() -> MetadataContext:
+    global local
+    contexts = getattr(local, 'contexts', [])
+    if not contexts:
+        try:
+            from metadata.cli.auth import get_context_from_conf, get_current_context_conf
+            conf = get_current_context_conf()
+            if not conf:
+                return
+            context = get_context_from_conf(conf)
+            if context:
+                contexts = [context]
+                setattr(local, 'contexts', contexts)
+        except Exception as e:
+            logger.warn('found invalid context, take `metadata login` to refresh context, %s', e)
+    return contexts[-1] if contexts else None
\ No newline at end of file
